Module sharing

Module sharing 

Constants

SECRET_SIZE_BYTES
SHARE_SIZE_BYTES

Functions

create_curve
Adi Shamir’s t-out-of-k secret sharing scheme, where only t out of k total shares are required to recover the secret, and the secret can be contained in 256 bits.
distribute
Creates K shares of a 256-bit secret, out of which T are required to reconstruct the secret.
reconstruct
Combines T shares of a secret.

Type Aliases

Secret256
A 256-bit secret
Share256
A share of a 256-bit secret