Constants
Functions
- create_
curve - Adi Shamir’s t-out-of-k secret sharing scheme, where only t out of k total shares are required to recover the secret, and the secret can be contained in 256 bits.
- distribute
- Creates K shares of a 256-bit secret, out of which T are required to reconstruct the secret.
- reconstruct
- Combines T shares of a secret.